==> katapult-trinity_3.5.13.2.orig.tar.xz: katapult-trinity-3.5.13.2/katapult/common/katapultdisplay.cpp <==
/***************************************************************************
 *   Copyright (C) 2005 by Joe Ferris                                      *
 *   jferris@optimistictech.com                                            *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.             *
 ***************************************************************************/

#include "katapultdisplay.moc"

#include "katapultdisplay.h"

KatapultDisplay::KatapultDisplay(const char *name, WFlags f)
	: TQWidget(0, name, f)
{
	_query = "";
	_item = 0;
	_action = 0;
	_status = 0;
	_selectionLength = 0;
}

KatapultDisplay::~KatapultDisplay()
{
}

void KatapultDisplay::focusOutEvent(TQFocusEvent *)
{
	emit focusOut();
}

void KatapultDisplay::keyPressEvent(TQKeyEvent *e)
{
	emit keyReleased(e);
}

// Deprecated - added for backwards compatibility
void KatapultDisplay::keyReleaseEvent(TQKeyEvent *e)
{
}

void KatapultDisplay::setQuery(TQString _query)
{
	this->_query = _query;
}

void KatapultDisplay::setSelected(unsigned int length)
{
	_selectionLength = length;
}

unsigned int KatapultDisplay::selected() const
{
	return _selectionLength;
}

void KatapultDisplay::setItem(const KatapultItem *_item)
{
	this->_item = _item;
}

void KatapultDisplay::setAction(const KatapultAction *_action)
{
	this->_action = _action;
}

void KatapultDisplay::setStatus(int _status)
{
	this->_status = _status;
}

TQString KatapultDisplay::query() const
{
	return _query;
}

const KatapultItem * KatapultDisplay::item() const
{
	return _item;
}

const KatapultAction * KatapultDisplay::action() const
{
	return _action;
}

int KatapultDisplay::status() const
{
	return _status;
}

void KatapultDisplay::readSettings(KConfigBase *)
{
}

void KatapultDisplay::writeSettings(KConfigBase *)
{
}

TQWidget * KatapultDisplay::configure()
{
	return 0;
}

==> katapult-trinity-14.1.5.tar.xz: katapult-trinity-14.1.5/katapult/common/katapultdisplay.cpp <==
/***************************************************************************
 *   Copyright (C) 2005 by Joe Ferris                                      *
 *   jferris@optimistictech.com                                            *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.             *
 ***************************************************************************/

#include "katapultdisplay.moc"

#include "katapultdisplay.h"

KatapultDisplay::KatapultDisplay(const char *name, WFlags f)
	: TQWidget(0, name, f)
{
	_query = "";
	_item = 0;
	_action = 0;
	_status = 0;
	_selectionLength = 0;
}

KatapultDisplay::~KatapultDisplay()
{
}

void KatapultDisplay::focusOutEvent(TQFocusEvent *)
{
	emit focusOut();
}

void KatapultDisplay::keyPressEvent(TQKeyEvent *e)
{
	emit keyReleased(e);
}

// Deprecated - added for backwards compatibility
void KatapultDisplay::keyReleaseEvent(TQKeyEvent *e)
{
}

void KatapultDisplay::setQuery(TQString _query)
{
	this->_query = _query;
}

void KatapultDisplay::setSelected(unsigned int length)
{
	_selectionLength = length;
}

unsigned int KatapultDisplay::selected() const
{
	return _selectionLength;
}

void KatapultDisplay::setItem(const KatapultItem *_item)
{
	this->_item = _item;
}

void KatapultDisplay::setAction(const KatapultAction *_action)
{
	this->_action = _action;
}

void KatapultDisplay::setStatus(int _status)
{
	this->_status = _status;
}

TQString KatapultDisplay::query() const
{
	return _query;
}

const KatapultItem * KatapultDisplay::item() const
{
	return _item;
}

const KatapultAction * KatapultDisplay::action() const
{
	return _action;
}

int KatapultDisplay::status() const
{
	return _status;
}

void KatapultDisplay::readSettings(TDEConfigBase *)
{
}

void KatapultDisplay::writeSettings(TDEConfigBase *)
{
}

TQWidget * KatapultDisplay::configure()
{
	return 0;
}
